Learn R Programming

rcontroll (version 0.1.2)

TROLLv3_daytimevar: TROLL daytime variation parameters

Description

Daytime variation parameters used by TROLLs models.

Usage

TROLLv3_daytimevar

Arguments

Format

A data frame with 24 rows and 5 variables:

starttime

starting time

endtime

ending time

vardaytime_light

daily variation in irradiance relative to the mean value of the day

vardaytime_vpd

daily variation in vapour pressure deficit relative to the mean value of the day

vardaytime_T

daily variation in temperature relative to the mean value of the day

See Also

generate_climate(), TROLLv3_climatedaytime12