Learn R Programming

rcontroll (version 0.1.2)

TROLLv3_output: TROLL output

Description

TROLL outputs from a 100-year simulation on a 100x100 grid with the other default parameters and using TROLLv3_species, TROLLv3_climatedaytime12, and TROLLv3_daytimevar for use in tests and examples. Ecosystem level output has been thinned and species output has been removed to save disk space.

Usage

TROLLv3_output

Arguments

Format

A trollsim() object.

See Also

TROLLv3_species(), TROLLv3_climatedaytime12(), TROLLv3_daytimevar(), troll()